import setuptools

setuptools.setup(
      name="pycontainerutils",    # 패키지 명
      version='0.0.0.2',
      license='MIT',
      author='greenrain',
      author_email='kdwkdw0078@gmail.com',
      description='docker container utilities',
      long_description=open('README.md').read(),
      url="https://github.com/greenrain78",
      packages=setuptools.find_packages(),
)
